pub struct CapacitanceRate(/* private fields */);Expand description
Capacitance rate (m_dot * c_p) of a working fluid in a heat exchanger.
The value must be strictly positive.
Implementations
Sourceimpl CapacitanceRate
impl CapacitanceRate
Sourcepub fn new<U>(value: f64) -> ConstraintResult<Self>
pub fn new<U>(value: f64) -> ConstraintResult<Self>
Create a CapacitanceRate from a scalar value.
Errors
Returns Err if the value is not strictly positive.
Sourcepub fn from_quantity(quantity: ThermalConductance) -> ConstraintResult<Self>
pub fn from_quantity(quantity: ThermalConductance) -> ConstraintResult<Self>
Create a CapacitanceRate from a quantity with thermal-conductance units.
Errors
Returns Err if the quantity is not strictly positive.
Sourcepub fn from_mass_rate_and_specific_heat(
mass_rate: MassRate,
specific_heat: SpecificHeatCapacity,
) -> ConstraintResult<Self>
pub fn from_mass_rate_and_specific_heat( mass_rate: MassRate, specific_heat: SpecificHeatCapacity, ) -> ConstraintResult<Self>
Create a CapacitanceRate from a mass rate and specific heat
capacity.
Errors
Returns Err if either operand is not strictly positive.